Buttons example - Format output data - export options

# Buttons example Format output data - export options

Buttons has two different methods that can be used to format the data exported differently from the data that is shown in the table: orthogonal options and formatting functions as shown in this example. They both achieve basically the same thing in different ways: namely modification of the output data.

Formatting functions for export buttons are specified by assigning a function to one (or more) of the `format` object of the `exportOptions` object. Three formatting functions can be used: `header`, `footer` and `body`. This is the primarily advantage of using formatting functions over orthogonal data - the header and footer can also be formatted using this method (of course orthogonal and this formatting function method can both be used together if you prefer!).

This example uses a `body` formatting function to remove the `$` and `,` characters from the final column to make it a numeric value in the output data. Since this is common to all three export buttons used, the function is placed into an object that is reused by each button - simply to save repeating the same code! This is not required, but it can be a useful technique.

Name | Position | Office | Extn. | Start date | Salary
--- | --- | --- | --- | --- | ---
Name | Position | Office | Extn. | Start date | Salary

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { var buttonCommon = { exportOptions: { format: { body: function ( data, row, column, node ) { // Strip $ from salary column to make it numeric return column === 5 ? data.replace( /[$,]/g, '' ) : data; } } } }; $('#example').DataTable( { ajax: '../../../../examples/ajax/data/objects.txt', columns: [ { data: 'name' }, { data: 'position' }, { data: 'office' }, { data: 'extn' }, { data: 'start_date' }, { data: 'salary' } ], dom: 'Bfrtip', buttons: [ $.extend( true, {}, buttonCommon, { extend: 'copyHtml5' } ), $.extend( true, {}, buttonCommon, { extend: 'excelHtml5' } ), $.extend( true, {}, buttonCommon, { extend: 'pdfHtml5' } ) ] } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- //code.jquery.com/jquery-1.12.4.js
- ../../../../media/js/jquery.dataTables.js
- ../../js/dataTables.buttons.js
- //cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js
- //cdn.rawgit.com/bpampuch/pdfmake/0.1.27/build/pdfmake.min.js
- //cdn.rawgit.com/bpampuch/pdfmake/0.1.27/build/vfs_fonts.js
- ../../js/buttons.html5.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../../../media/css/jquery.dataTables.css
- ../../css/buttons.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.